@@ -15,16 +15,16 @@
 # for use by other researchers. We require that the attributions
 # are retained with each function.
 ######################################################################
+######################################################################
 #
 # .First.lib is run when the package is loaded.
 #
 
 .First.lib <- function(lib, pkg){
-    ehelp <- library(help="statnet",lib.loc=NULL,character.only=TRUE)$info[[1]]
-    cat(paste(substring(ehelp[4],first=16),"\n",
-              "Version ",substring(ehelp[2],first=16),
-              " created on ",
-               substring(ehelp[3],first=16),".\n", sep=""))
+    DESCpath <- file.path(system.file(package="statnet"), "DESCRIPTION")
+    info <- read.dcf(DESCpath)
+    cat('\nstatnet:', info[,"Title"], 
+        '\nVersion', info[,"Version"], 'created on', info[,"Date"], '\n') 
     cat(paste("copyright (c) 2003, Mark S. Handcock, University of Washington\n",
 "                    David R. Hunter, Penn State University\n",
 "                    Carter T. Butts, University of California-Irvine\n",
@@ -35,5 +35,3 @@
         'For license and citation information see http://statnetproject.org/attribution\n',
         'or type citation("statnet").\n')
 }
-
-
